@@ -7,16 +7,17 @@ from bouncer.constants import *
 
 
 
-def bounce(action, subject):
+def ensure(action, subject):
     current_user = get_current_user()
     ability = Ability(current_user)
+    ability.authorization_method = current_app.bouncer.get_authorization_method()
     ability.alias_actions = current_app.bouncer.alias_actions
     if ability.cannot(action, subject):
         msg = "{} does not have {} access to {}".format(current_user, action, subject)
         raise Unauthorized(msg)
 
 #alais
-ensure = bounce
+bounce = ensure
 
 
 def get_current_user():
@@ -56,6 +57,7 @@ class Bouncer(object):
 
         self._alias_actions = self.default_alias_actions
 
+        self._authorization_method = None
 
     @property
     def alias_actions(self):
@@ -78,11 +80,15 @@ class Bouncer(object):
             self.flask_classy_classes = list()
         self.flask_classy_classes.extend(classy_routes)
 
-
-    def authorization_method(self, callback):
+    def authorization_method(self, value):
         """
         the callback for defining user abilities
         """
-        self.authorization_method_callback = callback
-        Ability.set_authorization_method(self.authorization_method_callback)
-        return callback
\ No newline at end of file
+        self._authorization_method = value
+        return self._authorization_method
+
+    def get_authorization_method(self):
+        if self._authorization_method is not None:
+            return self._authorization_method
+        else:
+            raise Exception('Expected authorication method to be set')
\ No newline at end of file
